@@ -2,11 +2,13 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'Account',
+    'name_bg_BG': 'Фактури',
     'name_de_DE': 'Buchhaltung',
     'name_es_CO': 'Contabilidad',
     'name_es_ES': 'Contabilidad',
     'name_fr_FR': 'Comptabilité',
-    'version': '1.8.1',
+    'name_nl_NL': 'Boekhouden',
+    'version': '2.2.1',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -25,6 +27,22 @@ And with reports:
     - Third party balance
     - Aged balance
     - General journal
+''',
+    'description_bg_BG': '''Модул за сечоводтсво с:
+    - Общо счетоводство
+    - Управление на финансови години
+    - Управление на данъци
+    - Записи в дневници
+    - Съгласуване
+
+Прилежащи справки:
+    - Основен дневник
+    - Временен баланс
+    - Баланс
+    - Управление на приходи
+    - Баланс на външен партньор
+    - Хронологичен баланс
+    - Общ дневник
 ''',
     'description_de_DE': '''Buchhaltungsmodul mit:
     - Allgemeiner Buchhaltung
@@ -89,6 +107,22 @@ Et les rapports:
     - Balance des tiers
     - Balance agée
     - Journal général
+''',
+    'description_nl_NL': '''Financiële administratie met:
+    - Boekhouding
+    - Boekjaren beheer
+    - Belastingen
+    - Dagboeken
+    - Afletteren
+
+Met bijbehorende rapporten:
+    - Grootboek
+    - Proefbalans
+    - Balans
+    - Verlies- & winstrekening
+    - Openstaande posten
+    - Ouderdomsanalyse facturen
+    - Algemeen dagboek
 ''',
     'depends': [
         'ir',
@@ -107,9 +141,13 @@ Et les rapports:
         'party.xml',
     ],
     'translation': [
-        'de_DE.csv',
-        'es_CO.csv',
-        'es_ES.csv',
-        'fr_FR.csv',
+        'locale/bg_BG.po',
+        'locale/cs_CZ.po',
+        'locale/de_DE.po',
+        'locale/es_CO.po',
+        'locale/es_ES.po',
+        'locale/fr_FR.po',
+        'locale/nl_NL.po',
+        'locale/ru_RU.po',
     ],
 }
